# GenomeTk

<b>[This project is in active development and not currently recommended for public use.]</b>

The genome toolkit is a collection of methods for determining characteristics about genomes. 

## Install

The simplest way to install this package is through pip:
> sudo pip install genome_tk

GenomeTk relies on several other software packages:

TBD

## RNA search

Identification of rRNA genes is performed using the rRNA HMM models in [barrnap](https://github.com/tseemann/barrnap).

## Cite

If you find this package useful, please cite this git repository (https://github.com/dparks1134/GenomeTk)

## Copyright

Copyright © 2015 Donovan Parks. See LICENSE for further details.
